@@ -1,8 +1,3 @@
-#include <assert.h>
-#include <stdio.h>
-#include <errno.h>
-#include <time.h>
-
 #include "mod_cml.h"
 #include "mod_cml_funcs.h"
 #include "log.h"
@@ -10,6 +5,12 @@
 
 #include "stat_cache.h"
 
+#include <assert.h>
+#include <stdio.h>
+#include <errno.h>
+#include <time.h>
+#include <string.h>
+
 #ifdef USE_OPENSSL
 # include <openssl/md5.h>
 #else
@@ -105,7 +106,7 @@ static int c_to_lua_push(lua_State *L, int tbl, const char *key, size_t key_len,
 }
 
 
-int cache_export_get_params(lua_State *L, int tbl, buffer *qrystr) {
+static int cache_export_get_params(lua_State *L, int tbl, buffer *qrystr) {
 	size_t is_key = 1;
 	size_t i;
 	char *key = NULL, *val = NULL;
