@@ -1,7 +1,3 @@
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include "base.h"
 #include "log.h"
 #include "buffer.h"
@@ -9,9 +5,9 @@
 #include "plugin.h"
 #include "response.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
 
 typedef struct {
 	pcre_keyvalue_buffer *redirect;
@@ -203,7 +199,7 @@ static handler_t mod_redirect_uri_handler(server *srv, connection *con, void *p_
 			}
 		} else {
 			const char **list;
-			size_t start, end;
+			size_t start;
 			size_t k;
 
 			/* it matched */
@@ -213,16 +209,14 @@ static handler_t mod_redirect_uri_handler(server *srv, connection *con, void *p_
 
 			buffer_reset(p->location);
 
-			start = 0; end = pattern_len;
+			start = 0;
 			for (k = 0; k < pattern_len; k++) {
 				if (pattern[k] == '$' || pattern[k] == '%') {
 					/* got one */
 
 					size_t num = pattern[k + 1] - '0';
 
-					end = k;
-
-					buffer_append_string_len(p->location, pattern + start, end - start);
+					buffer_append_string_len(p->location, pattern + start, k - start);
 
 					if (!isdigit((unsigned char)pattern[k + 1])) {
 						/* enable escape: "%%" => "%", "%a" => "%a", "$$" => "$" */
@@ -271,6 +265,7 @@ static handler_t mod_redirect_uri_handler(server *srv, connection *con, void *p_
 }
 
 
+int mod_redirect_plugin_init(plugin *p);
 int mod_redirect_plugin_init(plugin *p) {
 	p->version     = LIGHTTPD_VERSION_ID;
 	p->name        = buffer_init_string("redirect");
